==> liblxqt-0.15.1.tar.xz: liblxqt-0.15.1/translations/liblxqt_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog/lxqtconfigdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Діалог</translation>
    </message>
</context>
<context>
    <name>LXQt::MessageBox</name>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="76"/>
        <source>LXQt Power Manager Error</source>
        <translation>Збій менеджера живлення LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="76"/>
        <source>Hibernate failed.</source>
        <translation>Не вдалося приспати.</translation>
    </message>
</context>
<context>
    <name>LXQt::NotificationPrivate</name>
    <message>
        <location filename="../lxqtnotification.cpp" line="163"/>
        <source>Notifications Fallback</source>
        <translation>Резервне сповіщення</translation>
    </message>
</context>
<context>
    <name>LXQt::PowerManager</name>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="108"/>
        <source>Hibernate</source>
        <translation>Приспати</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="115"/>
        <source>Suspend</source>
        <translation>Призупинити</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="122"/>
        <source>Reboot</source>
        <translation>Перезавантажити</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="129"/>
        <source>Shutdown</source>
        <translation>Вимкнути</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="136"/>
        <source>Logout</source>
        <translation>Вийти</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="148"/>
        <source>LXQt Session Suspend</source>
        <translation>Призупинити комп’ютер</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="149"/>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>Дійсно призупинити комп’ютер?&lt;p&gt;Це переведе його в режим зниженого енергоспоживання. При втраті живлення стан системи не збережеться.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="158"/>
        <source>LXQt Session Hibernate</source>
        <translation>Приспати комп’ютер</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="159"/>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>Дійсно приспати комп’ютер?&lt;p&gt;Це переведе його в режим зниженого енергоспоживання. При втраті живлення стан системи збережеться.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="168"/>
        <source>LXQt Session Reboot</source>
        <translation>Перезавантажити комп’ютер</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="169"/>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>Дійсно перезавантажити комп’ютер? Усю незбережену роботу буде втрачено...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="178"/>
        <source>LXQt Session Shutdown</source>
        <translation>Вимкнути комп’ютер</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="179"/>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>Дійсно вимкнути комп’ютер? Усю незбережену роботу буде втрачено...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="188"/>
        <source>LXQt Session Logout</source>
        <translation>Вийти з сеансу LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="189"/>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>Дійсно завершити сеанс? Усю незбережену роботу буде втрачено...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="197"/>
        <location filename="../lxqtpowermanager.cpp" line="202"/>
        <source>LXQt Power Manager Error</source>
        <translation>Збій менеджера живлення LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="197"/>
        <source>Hibernate failed.</source>
        <translation>Не вдалося приспати.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="202"/>
        <source>Suspend failed.</source>
        <translation>Не вдалося призупинити.</translation>
    </message>
</context>
<context>
    <name>LXQt::ScreenSaver</name>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="160"/>
        <source>Failed to run  &quot;%1&quot;. Ensure you have a locker/screensaver compatible with xdg-screensaver installed and running.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="164"/>
        <source>Failed to run  &quot;%1&quot;. Ensure the specified locker/screensaver is installed and running.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="242"/>
        <source>Lock Screen</source>
        <translation>Заблокувати екран</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="155"/>
        <source>Screen Saver Error</source>
        <translation>Помилка зберігача екрану</translation>
    </message>
</context>
<context>
    <name>QCoreApplication</name>
    <message>
        <location filename="../configdialog/lxqtconfigdialogcmdlineoptions.cpp" line="49"/>
        <source>Choose the page to be shown.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="87"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="137"/>
        <source>Power Manager Error</source>
        <translation>Збій менеджера живлення</translation>
    </message>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="88"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="138"/>
        <source>QDBusInterface is invalid</source>
        <translation>QDBusInterface недійсний</translation>
    </message>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="102"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="152"/>
        <source>Power Manager Error (D-BUS call)</source>
        <translation>Збій менеджера живлення (виклик D-BUS)</translation>
    </message>
</context>
</TS>

==> liblxqt-1.0.0.tar.xz: liblxqt-1.0.0/translations/liblxqt_uk.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="uk">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog/lxqtconfigdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Діалог</translation>
    </message>
</context>
<context>
    <name>LXQt::MessageBox</name>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="76"/>
        <source>LXQt Power Manager Error</source>
        <translation>Збій менеджера живлення LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="76"/>
        <source>Hibernate failed.</source>
        <translation>Не вдалося приспати.</translation>
    </message>
</context>
<context>
    <name>LXQt::NotificationPrivate</name>
    <message>
        <location filename="../lxqtnotification.cpp" line="163"/>
        <source>Notifications Fallback</source>
        <translation>Резервне сповіщення</translation>
    </message>
</context>
<context>
    <name>LXQt::PowerManager</name>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="108"/>
        <source>Hibernate</source>
        <translation>Приспати</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="115"/>
        <source>Suspend</source>
        <translation>Призупинити</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="122"/>
        <source>Reboot</source>
        <translation>Перезавантажити</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="129"/>
        <source>Shutdown</source>
        <translation>Вимкнути</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="136"/>
        <source>Logout</source>
        <translation>Вийти</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="148"/>
        <source>LXQt Session Suspend</source>
        <translation>Призупинити комп’ютер</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="149"/>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>Дійсно призупинити комп’ютер?&lt;p&gt;Це переведе його в режим зниженого енергоспоживання. При втраті живлення стан системи не збережеться.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="158"/>
        <source>LXQt Session Hibernate</source>
        <translation>Приспати комп’ютер</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="159"/>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>Дійсно приспати комп’ютер?&lt;p&gt;Це переведе його в режим зниженого енергоспоживання. За втрати живлення стан системи збережеться.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="168"/>
        <source>LXQt Session Reboot</source>
        <translation>Перезавантажити комп’ютер</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="169"/>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>Дійсно перезавантажити комп’ютер? Усю незбережену роботу буде втрачено...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="178"/>
        <source>LXQt Session Shutdown</source>
        <translation>Вимкнути комп’ютер</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="179"/>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>Дійсно вимкнути комп’ютер? Усю незбережену роботу буде втрачено...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="188"/>
        <source>LXQt Session Logout</source>
        <translation>Вийти з сеансу LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="189"/>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>Дійсно завершити сеанс? Усю незбережену роботу буде втрачено...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="197"/>
        <location filename="../lxqtpowermanager.cpp" line="202"/>
        <source>LXQt Power Manager Error</source>
        <translation>Збій менеджера живлення LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="197"/>
        <source>Hibernate failed.</source>
        <translation>Не вдалося приспати.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="202"/>
        <source>Suspend failed.</source>
        <translation>Не вдалося призупинити.</translation>
    </message>
</context>
<context>
    <name>LXQt::ScreenSaver</name>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="160"/>
        <source>Failed to run  &quot;%1&quot;. Ensure you have a locker/screensaver compatible with xdg-screensaver installed and running.</source>
        <translation>Не вдалося запустити  «%1». Переконайтеся, що встановлено та запущено заставку, сумісну з xdg-заставкою.</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="164"/>
        <source>Failed to run  &quot;%1&quot;. Ensure the specified locker/screensaver is installed and running.</source>
        <translation>Не вдалося запустити  «%1». Переконайтеся, що вказану заставку встановлено та запущено.</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="242"/>
        <source>Lock Screen</source>
        <translation>Заблокувати екран</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="155"/>
        <source>Screen Saver Error</source>
        <translation>Помилка зберігача екрана</translation>
    </message>
</context>
<context>
    <name>QCoreApplication</name>
    <message>
        <location filename="../configdialog/lxqtconfigdialogcmdlineoptions.cpp" line="49"/>
        <source>Choose the page to be shown.</source>
        <translation>Виберіть сторінку для показу.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="87"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="137"/>
        <source>Power Manager Error</source>
        <translation>Збій менеджера живлення</translation>
    </message>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="88"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="138"/>
        <source>QDBusInterface is invalid</source>
        <translation>QDBusInterface недійсний</translation>
    </message>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="102"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="152"/>
        <source>Power Manager Error (D-BUS call)</source>
        <translation>Збій менеджера живлення (виклик D-BUS)</translation>
    </message>
</context>
</TS>
